
# Aura Engine Configuration Guide

This page goes into detail on what is possible to configure within the engine.

## Soundcard

Configure your audio device in the `[soundcard]` section of `engine.ini`.

You can configure up to **five** line IN and OUT stereo channels. Your hardware should
support that. When you use JACK, you will see the additional elements popping up when
viewing your connections (with e.g. Patchage).

**Pulse Audio:** When using Ubuntu, Pulse Audio is selected by default. This is convenient,
as you won't have the need to adapt any Engine setting to get audio playing initially.

**ALSA:** When you use ALSA, you will have to play around with ALSA settings. In the folder
`./modules/liquidsoap` is a scipt called alsa_settings_tester.liq. You can start it
with 'liquidsoap -v --debug alsa_settings_tester.liq'. Changing and playing with
settings may help you to find correct ALSA settings.

**Jack Audio**: Beside ALSA the sound servers such as 
is supported.

Install the JACK daemon and GUI:
```bash
    sudo apt-get install jackd qjackctl 
```

Please ensure to enable "*realtime process priority*" when installing JACK to keep latency low.
Now, you are able to configure your hardware settings using following command:

```bash
    qjackctl
```

Next you need to install the JACK plugin for Liquidsoap:

```bash
sudo apt install \
    liquidsoap-plugin-jack
```


## Recordings

You can configure up to **five** recorders in the `[recording]`.

## Streams

You can configure up to **five** streams in the `[streams]`.

## Fallbacks

Configure fallback handling in the `[fallback]` section.

## Database

Configure your engine database in the `[database]` section.

## Monitoring

Configure monitoring parameters in the `[monitoring]` section.

## Web User Interface

Configure the web interface in the `[web-ui]` section.

## Administrator Emails

Configure the email server for admin mails in the `[mail]` section.

## API Endpoints

Configure connections to the other Aura components in the `[dataurls]` section.

## Fading

Configure fading parameters in the `[fading]` section.

## Logging

Configure log handling in the `[logging]` section.

## User

Configure the executing system user in the `[user]` section.

## Socket

Configure socket connectivity in the `[socket]` section.

## Redis

Configure Redis connectivity in the `[redis]` section.


## Frequently Asked Questions

### Which Audio Interface / Soundcard is compatible with Aura?

Basically any audio device which is supported by Linux Debian/Ubuntu and has ALSA drivers.
Engine has been tested with following audio interfaces:

- ASUS Xonar DGX,
- Roland Duo-Capture Ex
- Onboard Soundcard (HDA Intel ALC262)
- Native Instruments Komplete Audio 6


### ALSA Settings

#### Install: I don't want to install all Liquidsoap Audio plugins. How?

Depending on what stream you are going to send, and what recordings you are going to use,
install one or some of the following:

```bash
sudo apt install \
    liquidsoap-plugin-aac # for aac support
    liquidsoap-plugin-flac # for flac support
    liquidsoap-plugin-lame liquidsoap-plugin-mad # for mp3 support
    liquidsoap-plugin-opus # for opus support
    liquidsoap-plugin-vorbis # for ogg support
```

#### In the Liquidsoap Logs I get 'Error when starting output output_lineout_0: Failure("Error while setting open_pcm: Device or resource busy")!'. What does it mean?

You probably have set a wrong or occupied device ID.


#### How can I find the audio device IDs, required for settings in engine.ini?

* **ALSA**: You can get the device numbers or IDs by executing:

    cat /proc/asound/cards

* **Pulse Audio**: You might not need this for Pulse Audio, but still, to see all available devices use:

    pactl list



**If you cannot find correct ALSA settings**  
Well, this is - at least for me - a hard one. I could not manage to find correct ALSA settings for the above mentioned soundcards. The best experience i had with the ASUS Xonar DGX, but still very problematic (especially the first couple of minutes after starting liquidsoap). Since i enabled JACK support i only use that. It is also a bit of trial and error, but works pretty much out of the box.

**If you experience 'hangs' or other artefacts on the output signal**
 * reduce the quality (especially, when hangs are on the stream) or
 * install the realtime kernel with

   ```bash
   apt install linux-image-rt-amd64
   reboot
   ```

   or
 * invest in better hardware